% Demo script for CovarSequence
%
% It shows how one can use reversion to numerically invert covariance
% relationships based on Hermite expansions using series reversion.

% Entry HermCoeffs(m) corresponds to Hermite coefficient c_{m-1} in
% the expansion f(x) = \sum_{m=0}^{M} c_m H_m(x) 
HermCoeffs = [0 1 1/2 1/4 1/16 1/64]; % i.e. [c_0,c_1,c_2] = [0, 1, 1] 

% NOTE: The current version of the code requires c_1~=0
zeropadLength = 51; % use this to increase the number of terms in the reversion series
[fwdSeq, revSeq] = CovarSequence(HermCoeffs, HermCoeffs,zeropadLength);
fwdSeq

z = linspace(-1,1,1000);

% calculate forward mapping
polyCoeff = fliplr([0 fwdSeq]); % setting constant term to 0 and flipping
g = polyval(polyCoeff,z);

% reversion
w = linspace(min(g),max(g),1000);
polyCoeff = fliplr([0 revSeq]); % setting constant term to 0 and flipping
ginv = polyval(polyCoeff,w);

figure(1); clf;
plot(z,g); hold on;
xaxislim = xlim; yaxislim = ylim;
plot(ginv,w,'r--');
axis([xaxislim yaxislim]);
xlabel('z (or ginv : inverse mapping)'); ylabel('g(z) : forward mapping (or w)');
legend('g','ginv');