% Demo for Multivariate non-Gaussian synthesis based on exact covariance
% mapping

% choose the transform type (see documentation of MapCovar)
name = 'LN';
%name = 'Gaussian';
params = [0 1]; % parameters for transform

% length of synthesized series
N = 2^10; 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate covariance structure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % set parameters for the FARIMA(0,D,0) model
W = [1 0.1;0 1];
d = [0.3 0.2];
Sigmae = eye(2);

% generate targeted covariance structure
Ncov = N+1; % cov. could be asymmetric, get cov. seq. of length N+1
RY = CovarFARIMA0D0(Ncov,d,W,Sigmae);

% normalize according to transform
RY = NormalizeCovar(RY,name,params);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate series
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[Y,RYapprox,K,funch,approxFlag] = GenMVnGaussUsingExactMap(RY,name,params,N);

if approxFlag,
    disp('Approximation was needed to ensure psd of inverted target covariance.');
else
    disp('Inverted target covariance was psd - no approximation needed.');
end
% Y(1,:) and Y(2,:) give realization of the two coordinates
Y1 = Y(1,:); Y2 = Y(2,:);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plots
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% plot the targeted auto- and cross-covariance sequences
figure;
subplot(411); plotcovar(RY,1,1); 
subplot(412); plotcovar(RY,2,2); 
subplot(413); plotcovar(RY,1,2);
subplot(414); plotcovar(RY,2,1);

% Plot |r^Y - \tilde{r}^Y| for each pair (p,p') of coordinates
ind = 1:N;
nn = ind-1;
for k=1:length(RY),
    for j=1:length(RY),
        figure;
        subplot(2,1,1);semilogy(nn,abs(RY{k,j}(ind)-RYapprox{k,j}(ind)));
        ylabelstr = sprintf('$|r^Y_{%d,%d} - \\tilde{r}^Y_{%d,%d}\\;|$',k,j,k,j);
        ylabel(ylabelstr,'interpreter','latex','fontsize',12);
        xlabel('$n$','interpreter','latex','fontsize',12);
        subplot(2,1,2);semilogy(nn,abs(RY{k,j}(ind)),nn,abs(RYapprox{k,j}(ind)),'r--');
        ylabelstr = sprintf('$r^Y_{%d,%d}$ and $(\\tilde{r}^Y_{%d,%d})$',k,j,k,j);
        ylabel(ylabelstr,'interpreter','latex','fontsize',12);
        xlabel('$n$','interpreter','latex','fontsize',12);        
    end
end

% plot a realization of the non-Gaussian series Y
figure;
subplot(211);plot(Y1);xlabel('n');ylabel('Y_1[n]');
subplot(212);plot(Y2);xlabel('n');ylabel('Y_2[n]');
