% Demo for univariate non-Gaussian synthesis

% choose the type of mapping Y[n]=F(X[n])
% see MapAutoCovar.m for other possibilities
name = 'Exp'; 
params = 1;   % parameter for the mapping

% length of synthesized process
N = 2^10;

% generate covariance
% set parameters for the AR(1) model
Phi = 0.8; sigmae = 1;
rY = CovarMAR1(N,Phi,sigmae);
% Scale generated covariance so the variance matches
% the targeted marginal
rY = NormalizeCovar(rY,name,params);

% synthesize series
[Y,rYapprox,K,funch,approxFlag] = GenUnivarNonGaussUsingExactMap(rY,name,params,N);

if approxFlag,
    disp('Targeted covariance could not be reached. rYapprox is the approximating covariance.');
else
    disp('Targeted covariance reached (no approximation needed).');
end
disp(['Number of Gaussian components used in transform: ' num2str(K)]);

% plot the auto-covariance sequences
figure;
subplot(211);
plotcovar(rY,1,1);
xlabel('n'); ylabel('r_Y[n]');
title(sprintf('Targeted covariance for non-Gaussian process: Y[n]=F(X[n]), name=''%s''',name));
subplot(212);
plotcovar(rYapprox,1,1);
xlabel('n'); ylabel('r_{Y,approx}[n]');
title(sprintf('Resulting covariance for non-Gaussian process: Y[n]=F(X[n]), name=''%s''',name));

% plot a realization of the process
figure;
plot(Y);
xlabel('n'); ylabel('Y[n]');
title(sprintf('Non-Gaussian process: Y[n]=F(X[n]), name=''%s''',name));
