% Demo for univariate non-Gaussian synthesis using Hermite expansions

% Define mapping
v = 1; % number of degrees of freedom
funch = @(x) chi2inv(normcdf(x),v);
varMarg = 2;    % the variance of the marginal, to correctly scale generated
                % covariance below

% length of synthesized process
N = 2^10;

% generate covariance
% set parameters for the AR(1) model
Phi = 0.8; sigmae = 1;
rY = CovarMAR1(N,Phi,sigmae);
% Scale generated covariance so the variance matches
% the targeted marginal
rY = varMarg/rY{1}(1)*rY{1};

% Scale generated covariance so the variance matches
% the targeted marginal

% synthesize series
[Y,rYapprox,coeffs,X,rXapprox,BmArray,approxFlag] = ... 
    GenUnivarNonGaussUsingHermite(rY,funch,N);


if approxFlag,
    disp('Targeted covariance could not be reached. rYapprox is the approximating covariance.');
else
    disp('Targeted covariance reached (no approximation needed).');
end

% plot the auto-covariance sequences
figure;
subplot(211);
plotcovar(rY,1,1);
xlabel('n'); ylabel('r_Y[n]');
title('Targeted covariance for non-Gaussian series');
subplot(212);
plotcovar(rYapprox,1,1);
xlabel('n'); ylabel('r_{Y,approx}[n]');
title('Resulting covariance for non-Gaussian series');

% plot a realization of the process
figure;
plot(Y);
xlabel('n'); ylabel('Y[n]');
title('Non-Gaussian series: Y[n]=f(X[n])');
