% Demo for Multivariate non-Gaussian synthesis based on Hermite expansions

% define the functions f_p, p=1,...,P, in the transforms Y_p = f_p(X_p)
P = 2;
funchArray = cell(1,P);

% using the same function for all coordinates
mu = 2;
funch = @(x) expinv(normcdf(x),mu);
for k=1:P,
    funchArray{k} = funch;
end
% To use different mappings:
% funchArray{1} = funch1;
%   ...
% funchArray{P} = funchP;
% where funch1,...,funchP are function handles

% length of synthesized series
N = 2^14; 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate covariance structure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % set parameters for the FARIMA(0,D,0) model
W = [1 0.1;0 1];
d = [0.3 0.2];
Sigmae = eye(2);

% generate targeted covariance structure
Ncov = N+1; % cov. could be asymmetric, get cov. seq. of length N+1
RY = CovarFARIMA0D0(Ncov,d,W,Sigmae);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Example 1: Monte Carlo synthesis using wrapper (where memory is not an
%            issue)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
numRealizations = 10; % number of Monte Carlo realizations
tic;
[Y,RYapprox,approxFlag] = GenMVnGaussUsingHermite(RY,funchArray,N,numRealizations);
wrapperTime = toc
if approxFlag,
    disp('Approximation was needed to ensure psd of inverted target covariance.');
else
    disp('Inverted target covariance was psd - no approximation needed.');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Example 2: Monte Carlo synthesis calling routines directly.
%
%            For long series and many components where memory could be
%            an issue this is one possibility.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% initalize
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% initialization step for multivariate Gaussian synthesis
tic;
[RYapprox,approxFlag,BmArray,coeffs,RXapprox] = InitMVnGaussUsingHermite(RY,funchArray,N);
initTime = toc
if approxFlag,
    disp('Approximation was needed to ensure psd of inverted target covariance.');
else
    disp('Inverted target covariance was psd - no approximation needed.');
end

X = cell(1,P);
Ycopy1 = zeros(P,N);
Ycopy2 = zeros(P,N);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate series
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
numRealizations = 10; % number of Monte Carlo realizations

tic;
for n=1:ceil(numRealizations/2),
    [Xcopy1,Xcopy2] = SynthStepMultivarGaussBestApprox(BmArray,N);        
    % recall that Xcopy1 and Xcopy2 are independent copies of a
    % multivariate Gaussian series
    
    % Transform Gaussian series: Y_p=f_p(X_p)
    for p=1:P,
        Ycopy1(p,:) = funchArray{p}(Xcopy1(p,:));
    end
    for p=1:P,
        Ycopy2(p,:) = funchArray{p}(Xcopy2(p,:));
    end
    % Ycopy1(1,:),...,Ycopy1(P,:) and Ycopy2(1,:),...,Ycopy2(P,:) are two
    % indepedent realizations of the multivariate series

    % Process Ycopy1 and Ycopy2...
    
    
end
toc