function [X1,Y1,X2,Y2] = SynthStepBivarGauss(sqrtLx, sqrtLy, Sxy, N)
% Generate bivariate stationary Gaussian series,
% provided preprocessed information from PreprocLambda
%
% Usage:
% [X1,Y1,X2,Y2] = SynthStepBivarGauss(sqrtLx, sqrtLy, Sxy, N)
%
% Inputs:
%   sqrtLx, sqrtLy, Sxy, N  see documentation given in InitBivarGauss
% Outputs:
%   (X1,Y1) and (X2,Y2) are two independent realizations of the series
%
% Copyright (c) Hannes Helgason, ENS Lyon, 2009

Ncirc = length(sqrtLx);

% Generate Zx
Zx = randn(1,Ncirc) + i*randn(1,Ncirc);

% Generate Zy
V = randn(1,Ncirc) + i*randn(1,Ncirc);
rho = abs(Sxy);
Vfact = sqrt(1-rho.^2/4);
Zy = conj(Sxy)/2 .* Zx + Vfact.*V;

% generate X
tmp = sqrtLx.*Zx;
Xbig = sqrt(Ncirc)*ifft(tmp); % multiplying with sqrt(N) to normalize IDFT correctly

% generate Y
tmp = sqrtLy.*Zy;
Ybig = 1/sqrt(Ncirc)*fft(tmp);

% the first N entries of the real and imaginary parts
% are independent realizations of W
X1 = real(Xbig(1:N));
Y1 = real(Ybig(1:N));
X2 = imag(Xbig(1:N));
Y2 = imag(Ybig(1:N));
