function val = HermiteExpansionEval(x,coeffs)
% Evaluate Hermite expansion
% 
% Usage:
%   val = HermiteExpansionEval(x,coeffs)
%
% Evaluates \sum_{m=0}^M coeffs(m+1) H_m(x), where H_m are Hermite polynomials
% normalized such that <H_m,H_m>:=E(H_m(X)H_m(X))=m!, where X~N(0,1) 
%
% Copyright 2009 (c), Hannes Helgason, ENS Lyon

% find the order of the expansion
M = length(coeffs)-1;

[numrowsx,numcolsx] = size(x); % the code is not vectorized... yet
% PEND: To speed up calculations, one could precompute the coefficients of the
% Hermite polynomials... or just implement this in C and use mex-interface

val = zeros(size(x));

% for row=1:numrowsx,
%   for col=1:numcolsx,
%      tmp = 0;
%      for m=0:M,
%        tmp = tmp + coeffs(m+1)*HermitePolyvalmex(x(row,col),m);
%      end
%      val(row,col) = tmp;
%   end
% end

for m=0:M,
    val = val + coeffs(m+1)*HermitePolyval(x,m);
end