function plotcovar(R,k,j)
% Plot a particular covariance sequence given the full covariance structure
%
% Usage:
%   plotcovar(R,k,j)
% Inputs
%   R      covariance structure (stored in a cell array of a size P-by-P)
%   k,j    the covariance sequence r_{k,j} will be plotted
%          these parameters need to be integers satisfying 1<=k,j<=P
%
% Remark: The plot is based on the sequences R{k,j} and R{j,k}.
%         If R{j,k} is empty, the sequence is assumed to be symmetric
%         around zero and only R{k,j} will be used.
%
% Copyright (c) Hannes Helgason, ENS Lyon, 2009

P = size(R,1); % number of coordinates

if nargin < 3,
    error('Both the parameters "k" and "j" have to be provided!');
end

if k>P|j>P|k<1|j<1,
	error('"k" and "j" must satisfy 1<=k,j<=P (P: number of coordinates)');
end

% get covariance sequences
if iscell(R),
    rxy = R{k,j}; 
    if isempty(R{j,k}),
        ryx = R{k,j};
    else
        ryx = R{j,k};
    end
else
    % assuming R is a vector (univariate case)
    rxy = R;
    ryx = rxy;
end
N = length(rxy);
% splice together, r_{XY}(-n)=r_{YX}(n), 
% know r_{XY}(n) for lags n=-N+1,...,-1,0,1,...N-1
% omitting ryx(1) since rxy(1) also both corresponds to lag zero
rfull = [fliplr(ryx(2:end)) rxy];
nn = (-N+1):(N-1); 

plot(nn,rfull);
xlabel('n : time-lag');
ylabel(sprintf('r_{%d,%d}[n]',k,j));    
